pub struct AbTestManager { /* private fields */ }Expand description
Manages multi-variant A/B experiments.
Implementations
Sourceimpl AbTestManager
impl AbTestManager
Sourcepub fn create_experiment(&mut self, experiment: Experiment)
pub fn create_experiment(&mut self, experiment: Experiment)
Register a new experiment.
Sourcepub fn assign(&self, experiment_id: &str, user_id: &str) -> Option<Assignment>
pub fn assign(&self, experiment_id: &str, user_id: &str) -> Option<Assignment>
Deterministically assign a user to a variant using weighted FNV hash.
Returns None if the experiment doesn’t exist or is not Running.
Sourcepub fn record_outcome(
&mut self,
assignment: &Assignment,
success: bool,
cost: f64,
latency_ms: u64,
)
pub fn record_outcome( &mut self, assignment: &Assignment, success: bool, cost: f64, latency_ms: u64, )
Record an outcome for a previously made assignment.
Sourcepub fn results(&self, experiment_id: &str) -> Vec<ExperimentResult>
pub fn results(&self, experiment_id: &str) -> Vec<ExperimentResult>
Return aggregated results for all variants in an experiment.
Sourcepub fn statistical_significance(
r_a: &ExperimentResult,
r_b: &ExperimentResult,
) -> f64
pub fn statistical_significance( r_a: &ExperimentResult, r_b: &ExperimentResult, ) -> f64
Two-proportion z-test significance.
Returns p-value approximation using erfc: p = erfc(|z| / sqrt(2)).
Sourcepub fn winner(&self, experiment_id: &str) -> Option<String>
pub fn winner(&self, experiment_id: &str) -> Option<String>
Return the variant ID with the highest conversion rate if statistically significant (z > 1.96 for p < 0.05), or None.
Sourcepub fn auto_complete(&mut self, experiment_id: &str, now: u64) -> bool
pub fn auto_complete(&mut self, experiment_id: &str, now: u64) -> bool
Check end condition and mark experiment completed if met. Returns true if completed.