pub struct CircuitBreakerRegistry { /* private fields */ }Expand description
A registry of circuit breakers keyed by model name.
New entries are created lazily with the supplied default configuration.
Implementations
Sourceimpl CircuitBreakerRegistry
impl CircuitBreakerRegistry
Sourcepub fn new(default_config: CircuitBreakerConfig) -> Self
pub fn new(default_config: CircuitBreakerConfig) -> Self
Create a registry; new breakers will be created with default_config.
Sourcepub fn get(&self, model: &str) -> Arc<CircuitBreaker> ⓘ
pub fn get(&self, model: &str) -> Arc<CircuitBreaker> ⓘ
Get (or lazily create) the circuit breaker for model.
Sourcepub fn register(&self, model: String, config: CircuitBreakerConfig)
pub fn register(&self, model: String, config: CircuitBreakerConfig)
Register a circuit breaker for model with a specific configuration.