pub struct FeedbackStore { /* private fields */ }Expand description
Thread-safe ring buffer of the last capacity feedbacks per model variant.
Implementations
Sourceimpl FeedbackStore
impl FeedbackStore
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Create a new store that retains the last capacity feedbacks per variant.
Sourcepub fn push(&self, variant: &str, feedback: Feedback)
pub fn push(&self, variant: &str, feedback: Feedback)
Append a feedback for variant. Overwrites the oldest entry when full.