pub fn inc_dedup_hash_collision()Expand description
Increment the dedup hash collision counter.
Call when two different prompts are found to produce the same hash key in the deduplication layer, indicating a hash collision.
No-op if metrics have not been initialised.
Panics
This function never panics.