pub fn inc_inference_timeout()Expand description
Increment the inference timeout counter.
Call when an inference call is cancelled because it exceeded the configured timeout.
No-op if metrics have not been initialised.
pub fn inc_inference_timeout()Increment the inference timeout counter.
Call when an inference call is cancelled because it exceeded the configured timeout.
No-op if metrics have not been initialised.