pub struct ModelRegistry { /* private fields */ }Expand description
Concurrent registry of ModelMetadata keyed by model ID.
Implementations
Sourceimpl ModelRegistry
impl ModelRegistry
Sourcepub fn register(&self, model: ModelMetadata)
pub fn register(&self, model: ModelMetadata)
Register or replace a model’s metadata.
Sourcepub fn get(&self, model_id: &str) -> Option<ModelMetadata>
pub fn get(&self, model_id: &str) -> Option<ModelMetadata>
Look up a model by ID.
Sourcepub fn all_models(&self) -> Vec<ModelMetadata>
pub fn all_models(&self) -> Vec<ModelMetadata>
Return all registered models.
Sourcepub fn models_with_capability(
&self,
cap: &ModelCapability,
) -> Vec<ModelMetadata>
pub fn models_with_capability( &self, cap: &ModelCapability, ) -> Vec<ModelMetadata>
Return non-deprecated models that have cap, sorted by cheapest input cost first.
Sourcepub fn cheapest_for_capability(
&self,
cap: &ModelCapability,
min_context: usize,
) -> Option<ModelMetadata>
pub fn cheapest_for_capability( &self, cap: &ModelCapability, min_context: usize, ) -> Option<ModelMetadata>
Return the cheapest model that has cap and fits within min_context tokens.
Sourcepub fn best_for_capability(
&self,
cap: &ModelCapability,
min_context: usize,
) -> Option<ModelMetadata>
pub fn best_for_capability( &self, cap: &ModelCapability, min_context: usize, ) -> Option<ModelMetadata>
Return the highest-tier model that has cap and fits within min_context tokens.
Sourcepub fn suggest_routing(
&self,
caps: &[ModelCapability],
context_size: usize,
budget_usd: Option<f64>,
) -> RoutingHint
pub fn suggest_routing( &self, caps: &[ModelCapability], context_size: usize, budget_usd: Option<f64>, ) -> RoutingHint
Suggest a routing strategy given required capabilities, context size, and optional budget.
Sourcepub fn built_in_registry() -> Self
pub fn built_in_registry() -> Self
Build a registry pre-populated with well-known models.
Sourcepub fn rate_limit_check(
&self,
model_id: &str,
requests_last_minute: u32,
tokens_last_minute: u32,
) -> bool
pub fn rate_limit_check( &self, model_id: &str, requests_last_minute: u32, tokens_last_minute: u32, ) -> bool
Check whether a model is within its rate limits.
Returns true if the model can accept more requests/tokens, false if a limit is exceeded.
Sourcepub fn deprecation_warnings(&self) -> Vec<String>
pub fn deprecation_warnings(&self) -> Vec<String>
Return deprecation warning strings for all deprecated models.