pub struct ObservabilityRegistry {
pub tracer: Arc<Tracer>,
pub metrics: Arc<Mutex<Vec<MetricPoint>>>,
}Expand description
Central registry that combines a Tracer with an in-process metrics
store and Prometheus export.
Fields
tracer: Arc<Tracer>The tracer used to create spans.
metrics: Arc<Mutex<Vec<MetricPoint>>>Accumulated metric observations.
Implementations
Sourceimpl ObservabilityRegistry
impl ObservabilityRegistry
Sourcepub fn record_metric(
&self,
name: &str,
value: f64,
labels: HashMap<String, String>,
)
pub fn record_metric( &self, name: &str, value: f64, labels: HashMap<String, String>, )
Records a metric observation.
Sourcepub fn to_prometheus(&self) -> String
pub fn to_prometheus(&self) -> String
Serializes all recorded metrics in the Prometheus exposition format.
Each metric is emitted as:
metric_name{label="value",...} <value> <timestamp_ms>Auto Trait Implementations
impl !RefUnwindSafe for ObservabilityRegistry
impl !UnwindSafe for ObservabilityRegistry
impl Freeze for ObservabilityRegistry
impl Send for ObservabilityRegistry
impl Sync for ObservabilityRegistry
impl Unpin for ObservabilityRegistry
impl UnsafeUnpin for ObservabilityRegistry