pub struct Tracer { /* private fields */ }Expand description
Creates and manages spans, routing finished spans to the configured exporter.
Implementations
Sourceimpl Tracer
impl Tracer
Sourcepub fn new(exporter: Arc<dyn SpanExporter>) -> Self
pub fn new(exporter: Arc<dyn SpanExporter>) -> Self
Creates a tracer that will send completed spans to exporter.
Sourcepub fn start_span(&self, name: &str) -> Span
pub fn start_span(&self, name: &str) -> Span
Starts a new root span with the given name. The span is sampled by default.
Sourcepub fn start_child_span(&self, name: &str, parent: &Span) -> Span
pub fn start_child_span(&self, name: &str, parent: &Span) -> Span
Starts a child span whose parent_span_id is set to the parent
span’s span_id.
Sourcepub fn finish_span(&self, span: Span)
pub fn finish_span(&self, span: Span)
Finishes and exports span.