pub struct ResponseLengthCapPlugin {
pub max_tokens: usize,
}Expand description
A plugin that truncates response token lists to at most max_tokens items.
Fields
max_tokens: usizeMaximum number of token strings to keep in the response.
Implementations