pub struct Template { /* private fields */ }Expand description
A pre-parsed template that can be rendered repeatedly with different contexts.
Implementations
Sourceimpl Template
impl Template
Sourcepub fn render(&self, ctx: &TemplateContext) -> Result<String, TemplateError>
pub fn render(&self, ctx: &TemplateContext) -> Result<String, TemplateError>
Render this template with the given context.
Sourcepub fn variables(&self) -> Vec<String>
pub fn variables(&self) -> Vec<String>
Return all variable names referenced in {{ ... }} expressions.
Sourcepub fn validate(&self) -> Result<(), TemplateError>
pub fn validate(&self) -> Result<(), TemplateError>
Validate that all blocks are properly paired without rendering.