pub struct ProviderSnapshot {
pub name: String,
pub cost_per_1k_input_tokens: f64,
pub cost_per_1k_output_tokens: f64,
pub priority: u32,
pub p50_latency_ms: Option<f64>,
pub p95_latency_ms: Option<f64>,
pub total_requests: u64,
pub error_rate: f64,
pub input_tokens: u64,
pub output_tokens: u64,
}Expand description
Point-in-time snapshot of a single provider’s state.
Fields
name: StringProvider name.
cost_per_1k_input_tokens: f64Input token cost per 1K tokens (USD).
cost_per_1k_output_tokens: f64Output token cost per 1K tokens (USD).
priority: u32Priority for tie-breaking (lower = preferred).
p50_latency_ms: Option<f64>P50 (median) latency in milliseconds, or None if no samples yet.
p95_latency_ms: Option<f64>P95 latency in milliseconds, or None if no samples yet.
total_requests: u64Total requests routed to this provider.
error_rate: f64Error rate (0.0 – 1.0).
input_tokens: u64Total input tokens sent.
output_tokens: u64Total output tokens received.