pub struct SessionManager { /* private fields */ }Expand description
Concurrent, lock-free store of Sessions keyed by u64 ID.
All methods are &self and safe to call from multiple Tokio tasks.
Implementations
Sourceimpl SessionManager
impl SessionManager
Sourcepub fn create(&self, system_prompt: Option<String>) -> u64
pub fn create(&self, system_prompt: Option<String>) -> u64
Create a new session, optionally pre-loading a system message.
Returns the new session’s ID.
Sourcepub fn append(
&self,
session_id: u64,
role: Role,
content: String,
) -> Result<(), SessionError>
pub fn append( &self, session_id: u64, role: Role, content: String, ) -> Result<(), SessionError>
Append a message to an existing session.
Token count is estimated as word count when not supplied.
Sourcepub fn get(&self, session_id: u64) -> Result<Session, SessionError>
pub fn get(&self, session_id: u64) -> Result<Session, SessionError>
Return a copy of the session, or Err(SessionError::NotFound).
Sourcepub fn get_context(
&self,
session_id: u64,
max_tokens: usize,
) -> Result<Vec<Message>, SessionError>
pub fn get_context( &self, session_id: u64, max_tokens: usize, ) -> Result<Vec<Message>, SessionError>
Return messages for a session trimmed to fit within max_tokens.
Strategy:
- The system message (if any) is always retained.
- Non-system messages are trimmed from the oldest end until the
total fits within
max_tokens.
Sourcepub fn summarize_if_needed(
&self,
session_id: u64,
threshold_tokens: usize,
summarizer: &dyn Fn(&str) -> String,
) -> Result<(), SessionError>
pub fn summarize_if_needed( &self, session_id: u64, threshold_tokens: usize, summarizer: &dyn Fn(&str) -> String, ) -> Result<(), SessionError>
If the session’s total tokens exceed threshold_tokens, call
summarizer on the oldest non-system messages and replace them with a
single assistant summary message.
Sourcepub fn stats(&self) -> SessionStats
pub fn stats(&self) -> SessionStats
Collect aggregate statistics across all stored sessions.