pub struct WorkerConfig {
pub min_workers: usize,
pub max_workers: usize,
pub idle_timeout_secs: u64,
pub queue_depth_per_worker: usize,
}Expand description
Configuration for a WorkerPool.
Fields
min_workers: usizeMinimum number of worker tasks to keep alive even when idle.
max_workers: usizeMaximum number of concurrent worker tasks.
idle_timeout_secs: u64Number of seconds a worker may be idle before it is allowed to exit
(only applies to workers above min_workers).
queue_depth_per_worker: usizeTarget queue depth per worker. When queue_depth > workers * queue_depth_per_worker the pool will attempt to scale up.