pub struct EvalHarness { /* private fields */ }Expand description
Evaluation harness for comparing prompt strategies.
Implementations
Sourceimpl EvalHarness
impl EvalHarness
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new harness with EvalMetric::ExactMatch as the primary metric.
Sourcepub fn with_metric(metric: EvalMetric) -> Self
pub fn with_metric(metric: EvalMetric) -> Self
Create a harness with a custom primary metric.
Sourcepub fn run_eval(
&self,
strategy_name: &str,
responses: Vec<(String, u64, f64)>,
) -> EvalReport
pub fn run_eval( &self, strategy_name: &str, responses: Vec<(String, u64, f64)>, ) -> EvalReport
Run an evaluation for strategy_name.
responses must be in the same order as cases were added. Each element
is (response_text, latency_ms, cost_usd).
Panics
Does not panic — if responses is shorter than cases, remaining cases
are skipped.
Sourcepub fn score(&self, response: &str, case: &EvalCase, metric: &EvalMetric) -> f64
pub fn score(&self, response: &str, case: &EvalCase, metric: &EvalMetric) -> f64
Score a single response against a case using the supplied metric.
Sourcepub fn compare_strategies(reports: &[EvalReport]) -> Vec<(&EvalReport, f64)>
pub fn compare_strategies(reports: &[EvalReport]) -> Vec<(&EvalReport, f64)>
Rank strategies by composite score: pass_rate * 0.6 - avg_cost_usd_norm * 0.2 - avg_latency_norm * 0.2.
Returns references to reports in descending composite score order.
Sourcepub fn filter_by_tag(&self, tag: &str) -> Vec<&EvalCase>
pub fn filter_by_tag(&self, tag: &str) -> Vec<&EvalCase>
Return all cases tagged with tag.
Sourcepub fn difficulty_breakdown(&self, report: &EvalReport) -> HashMap<u8, f64>
pub fn difficulty_breakdown(&self, report: &EvalReport) -> HashMap<u8, f64>
Compute per-difficulty pass rate from a report.
Keys are difficulty levels (1–5); values are pass rates (0.0 – 1.0).