pub struct PipelineBuilder { /* private fields */ }Expand description
Fluent builder for Pipeline.
Implementations
Sourceimpl PipelineBuilder
impl PipelineBuilder
Sourcepub fn add_stage(self, name: &str, kind: StageKind) -> Self
pub fn add_stage(self, name: &str, kind: StageKind) -> Self
Append a new stage with the given name and kind.
Sourcepub fn configure_stage(self, name: &str, key: &str, value: &str) -> Self
pub fn configure_stage(self, name: &str, key: &str, value: &str) -> Self
Set a configuration key/value pair on the most-recently added stage
named name. Does nothing if no stage with that name exists yet.
Sourcepub fn disable_stage(self, name: &str) -> Self
pub fn disable_stage(self, name: &str) -> Self
Disable the stage named name. Does nothing if no such stage exists.
Sourcepub fn fail_fast(self, v: bool) -> Self
pub fn fail_fast(self, v: bool) -> Self
Set whether the pipeline should abort on the first stage error.
Sourcepub fn build(self) -> Result<Pipeline, PipelineError>
pub fn build(self) -> Result<Pipeline, PipelineError>
Consume the builder and produce a Pipeline.
Returns PipelineError::EmptyPipeline if no stages were added.