pub enum RoutingDecision {
Local {
score: f64,
worker: WorkerKind,
},
LocalWithFallback {
score: f64,
primary: WorkerKind,
fallback: WorkerKind,
},
Cloud {
score: f64,
worker: WorkerKind,
},
}Expand description
Variants
Local
Route to the local model (complexity below local_threshold).
Fields

worker: WorkerKindThe worker kind selected.
LocalWithFallback
Route to the local model first, fall back to cloud on failure
(complexity between local_threshold and cloud_threshold).
Cloud
Route directly to the cloud model (complexity above cloud_threshold).
Fields

worker: WorkerKindThe worker kind selected.
Implementations
Sourceimpl RoutingDecision
impl RoutingDecision
Sourcepub fn is_local(&self) -> bool
pub fn is_local(&self) -> bool
Return true if the decision routes to the local worker exclusively.
Panics
This function never panics.
Sourcepub fn is_cloud(&self) -> bool
pub fn is_cloud(&self) -> bool
Return true if the decision routes to the cloud worker exclusively.
Panics
This function never panics.
Sourcepub fn is_fallback(&self) -> bool
pub fn is_fallback(&self) -> bool